Learn R Programming

gss (version 3.0-0)

clone: Cloning Smoothing Spline ANOVA Fits for Retrospective Inference

Description

Simulate replicates from smoothing spline ANOVA fits then calculate clones of the fits.

Usage

clone(object, ...)
# S3 method for ssanova
clone(object, nrep=1000, type=1, seed=NULL, eta=NULL,
fix=FALSE, ...)

# S3 method for gssanova
clone(object, nrep=1000, type=1, seed=NULL, eta=NULL,
fix=FALSE, ...)







Value

The function returns a list object of class clone, to be use as input to retroCI to product retrospective confidence intervals.

The input object is in element fit

Arguments

object

Object of class "ssanova" or "gssanova".

...

Additional arguments. Ignored in clone.x.

nrep

Number of clones to be generated.

type

type=1 tries to enforce effective constraints, type=2 searches for optimal performer, both via smoothing parameter selection.

seed

Seed to be used in random number generation; if NULL seed will be set internally to ensure reproducible results.

eta

True function values to generate replicates from; if NULL the fitted value of object will be used.

fix

Logical flag indicating whether to fix theta's with multiple smoothing parameters.

References

Gu, C. (2026), Retrospective statistical inference. Manuscript.

See Also

Fitting functions ssanova, gssanova.