Learn R Programming

gss (version 3.0-0)

project1: Projecting Smoothing Spline ANOVA Fits for Retrospective Testing

Description

Calculate Kullback-Leibler projection of smoothing spline ANOVA fits and calibrate using clone distribution under the null.

Usage

project1(object, ...)
# S3 method for ssanova
project1(object, include, nrep=200, type=1, ...)

# S3 method for gssanova
project1(object, include, nrep=200, type=1, ...)







Value

The functions return a list consisting of the following elements.

ratio

KL(fit0,fit1)/KL(fit0,null); the smaller the value, the more feasible the reduced model is.

kl

KL(fit0,fit1).

check

KL(fit0,fit1)/KL(fit0,null)+KL(fit1,null)/KL(fit0,null); a value closer to 1 is preferred.

pvalue

Retrospective p-value of ratio, calibrated against clone distribution under the null.

Arguments

object

Object of class "ssanova" or "gssanova".

...

Additional arguments. Ignored in project1.x.

include

List of model terms to be included in the reduced model space. The partial and offset terms, if present, are to be specified by "partial" and "offset", respectively.

nrep

Number of clones to be simulated under the null .

type

Clone type to use; see clone.

Details

The entropy KL(fit0,null) can be decomposed as the sum of KL(fit0,fit1) and KL(fit1,null), where fit0 is the fit to be projected, fit1 is the projection in the reduced model space, and null is the constant fit. The ratio KL(fit0,fit1)/KL(fit0,null) serves as a diagnostic of the feasibility of the reduced model.

The projection itself is exactly as in project, but with a retrospective p-value attached, calibrating against the clone distribution under the null using nrep simulated clones.

References

Gu, C. (2004), Model diagnostics for smoothing spline ANOVA models. The Canadian Journal of Statistics, 32, 347--358.

Gu, C. (2026), Retrospective statistical inference. Manuscript.

See Also

Fitting functions ssanova, gssanova, and cloning function clone.