Simulate replicates from smoothing spline ANOVA fits then calculate clones of the fits.
clone(object, ...)
# S3 method for ssanova
clone(object, nrep=1000, type=1, seed=NULL, eta=NULL,
fix=FALSE, ...)
# S3 method for gssanova
clone(object, nrep=1000, type=1, seed=NULL, eta=NULL,
fix=FALSE, ...)
The function returns a list object of class clone, to be use
as input to retroCI to product retrospective
confidence intervals.
The input object is in element fit
Object of class "ssanova" or "gssanova".
Additional arguments. Ignored in clone.x.
Number of clones to be generated.
type=1 tries to enforce effective constraints, type=2 searches for optimal performer, both via smoothing parameter selection.
Seed to be used in random number generation; if NULL seed will be set internally to ensure reproducible results.
True function values to generate replicates from; if NULL
the fitted value of object will be used.
Logical flag indicating whether to fix theta's with multiple smoothing parameters.
Gu, C. (2026), Retrospective statistical inference. Manuscript.
Fitting functions ssanova, gssanova.