Calculate Kullback-Leibler projection of smoothing spline ANOVA fits and calibrate using clone distribution under the null.
project1(object, ...)
# S3 method for ssanova
project1(object, include, nrep=200, type=1, ...)
# S3 method for gssanova
project1(object, include, nrep=200, type=1, ...)
The functions return a list consisting of the following elements.
KL(fit0,fit1)/KL(fit0,null); the smaller the value, the more feasible the reduced model is.
KL(fit0,fit1).
KL(fit0,fit1)/KL(fit0,null)+KL(fit1,null)/KL(fit0,null); a value closer to 1 is preferred.
Retrospective p-value of ratio, calibrated against clone distribution under the null.
Object of class "ssanova" or "gssanova".
Additional arguments. Ignored in project1.x.
List of model terms to be included in the reduced
model space. The partial and offset terms, if
present, are to be specified by "partial" and
"offset", respectively.
Number of clones to be simulated under the null .
Clone type to use; see clone.
The entropy KL(fit0,null) can be decomposed as the sum of KL(fit0,fit1) and KL(fit1,null), where fit0 is the fit to be projected, fit1 is the projection in the reduced model space, and null is the constant fit. The ratio KL(fit0,fit1)/KL(fit0,null) serves as a diagnostic of the feasibility of the reduced model.
The projection itself is exactly as in project, but
with a retrospective p-value attached, calibrating against the
clone distribution under the null using nrep simulated
clones.
Gu, C. (2004), Model diagnostics for smoothing spline ANOVA models. The Canadian Journal of Statistics, 32, 347--358.
Gu, C. (2026), Retrospective statistical inference. Manuscript.
Fitting functions ssanova, gssanova, and
cloning function clone.